PROGRAM Compute_nuInu
  USE CollapseFraction
  USE salpeter
! This code calculates the mean intensity of the near infrared background (NIRB).
! Ref: Fernandez and Komatsu, ApJ, 646, 703 (2006)
!      Fernandez et al., ApJ, 710, 1089 (2010)
!
! The assumptions are:
! - Salpeter's initial mass function for 3<m/Msun<150 [see salpeter.f90]
! - Metal-free (PopIII) stars [see pop3.f90]
! - Star Formation Rate is given by SFR=fstar*omega_b*rho_c0*fcoll(z)/tSF
!
! The code outputs two files:
! - nu*Inu [nW/m^2/str], 'hnu_nu_ff_fb_star_lya_2g_nuInu.txt'
! - nu*lnu [nW/Msun], 'hnu_nu_ff_fb_star_lya_2g_nulnu.txt'
! 1st column: h*nu [eV]
! 2nd column: nu [Hz]
! 3rd column: free-free
! 4th column: free-bound
! 5th column: stellar
! 6th column: Lyman-alpha
! 7th column: two-photon
!
! The first and second files may be compared to Fig.20 and 1 of 
! Fernandez et al. (2010), respectively.
!
! December 29, 2010: E.Komatsu
  IMPLICIT none
  double precision :: zend=6d0 ! end of star formation
  double precision :: fstar=1d-2 ! star formation efficiency
  double precision :: tSF=20d6 ! star formation time scale
  double precision :: zstart=15d0 ! the results are dominated by zend
  logical :: use_line_approximation=.true. !ignore radiation transfer of LyA?
  !!$double precision :: h0=0.702d0,ode0=0.723d0,om0=0.277d0,obh2=0.02262d0
  double precision :: h0=0.73d0,ode0=0.76d0,om0=0.24d0,obh2=0.02238d0
  double precision :: mpc2m=3.086d22,erg2nW=1d2,tol=1d-6
  double precision :: hnu,nu,nuInu,factor,mstar,Nstar,dz,Ez,z,zlya,nulya,x
  double precision :: nion,meanmass,norm,denom,res,nustar,rombint
  double precision :: Lnu_ff,Lnu_fb,Lnu_2g,L_lya,meanLnu_star,sum(5)
  double precision :: sfr,fcoll
  double precision :: h=4.1356668d-15 ! Planck's constant [eV s]
  double precision :: eV2erg=1.602d-12 ! erg/eV
  double precision :: pi=3.1415926535d0
  character(len=128) :: filename
  integer :: i,j,n,nsteps=2000
  external rombint,nion,meanmass,norm,fcoll
  external Lnu_ff,Lnu_fb,Lnu_2g,L_lya,meanLnu_star
  nulya=10.2d0/h
! read in and tabulate the collapse fraction
  filename='wmap5baosn_max_likelihood_pressschechter_redshift_fcoll.txt'
  n=301 ! # of lines in the file
  CALL open_fcoll(filename,n)
! compute the mean stellar mass and the mean number of ionizing photons
! for a given stellar population
  denom=rombint(norm,dlog(m1),dlog(m2),tol)
  mstar=rombint(meanmass,dlog(m1),dlog(m2),tol)/denom ! mean stellar mass [Msun]
  Nstar=rombint(nion,dlog(m1),dlog(m2),tol)/denom ! number of ionizing photons
  print*,'mean stellar mass=',mstar,' Msun'
  print*,'mean number of ionizing photons=',Nstar
! compute the mean NIRB spectrum, nu*Inu
  ! factor=(c/fourpi)/H0/mstar, in units of m^-2 s^-1
  factor=(2.998d8/(4d0*pi))/(1.023d-10*h0)/mstar/mpc2m**3d0 
  open(1,file='hnu_nu_ff_fb_star_lya_2g_nuInu.txt',status='unknown')
  do i=0,45
     hnu=0.2d0+dble(i)*4d-2 ! eV
     nu=hnu/h ! Hz
     sum=0d0
!!$ This section approximates the lyman-alpha as a line 
!!$ (i.e., ignore the radiative transfer of Lyman-alpha photons 
!!$ such as scattering)
     zlya=10.2d0/hnu-1d0
     if(use_line_approximation.and.(zlya.le.zstart).and.(zlya.ge.zend))then
        ! Star Formation Rate [Msun/Mpc^3/year]
        sfr=fstar*obh2*fcoll(zlya)*2.775d11/tSF/1.2d0 ! 1.2 is a fudge factor
        Ez=dsqrt(om0*(1d0+zlya)**3d0+ode0) ! H(z)/H0
        sum(4)=sfr*L_lya(nu*(1d0+zlya),Nstar)/Ez/(1d0+zlya)/nu ! erg/Hz
     endif
     do j=1,nsteps
        if(j.eq.1)then
           z=zend
           dz=0.5d0*(zstart-zend)/dble(nsteps-1)
        else if (j.eq.nsteps)then
           z=zstart
           dz=0.5d0*(zstart-zend)/dble(nsteps-1)
        else
           dz=(zstart-zend)/dble(nsteps-1)
           z=zend+dble(j-1)*dz
        endif
        ! Star Formation Rate [Msun/Mpc^3/year]
        sfr=fstar*obh2*fcoll(z)*2.775d11/tSF/1.2d0 ! 1.2 is a fudge factor
        Ez=dsqrt(om0*(1d0+z)**3d0+ode0) ! H(z)/H0
        sum(1)=sum(1)+dz*sfr*Lnu_ff(nu*(1d0+z),Nstar)/Ez/(1d0+z) ! erg/Hz
        sum(2)=sum(2)+dz*sfr*Lnu_fb(nu*(1d0+z),Nstar)/Ez/(1d0+z) ! erg/Hz
        CALL qromb(meanLnu_star,dlog(m1),dlog(m2),res,nu*(1d0+z))
        sum(3)=sum(3)+dz*sfr*(res/denom)/Ez/(1d0+z) ! erg/Hz
        sum(5)=sum(5)+dz*sfr*Lnu_2g(nu*(1d0+z),Nstar)/Ez/(1d0+z) ! erg/Hz
!!$ This section uses an extended profile of Lyman-alpha, but the difference
!!$ occurs only at low energies where the spectrum is dominated by the stellar
!!$ and two-photon emission. Therefore, the line approximation is sufficient.
!!$     ! Eq(16) of Santos et al., MNRAS, 336, 1082 (2002)
        nustar=1.5d11*(obh2/0.019d0)*(0.7d0/h0)*(1d0+z)**3d0/Ez
        x=nulya-nu*(1d0+z)
        if((.not.use_line_approximation).and.(x>0d0))then
           sum(4)=sum(4)+dz*sfr*Nstar*0.64d0*(10.2d0*eV2erg)/Ez/(1d0+zlya)&
                *nustar/x**2d0*dexp(-nustar/x) ! Eq(15) of Santos et al.
        endif
     enddo
     close(11)
     write(1,'(7E15.5)')hnu,nu,nu*sum(1:5)*factor*erg2nW ! nW/m^2/str
  enddo
  close(1)
  call close_fcoll
! write out the luminosity spectrum per stellar mass, nu*lnu [nW/Msun]
  open(1,file='hnu_nu_ff_fb_star_lya_2g_nulnu.txt',status='unknown')
  z=10d0
  Ez=dsqrt(om0*(1d0+z)**3d0+ode0) ! H(z)/H0
  nustar=1.5d11*(obh2/0.019d0)*(0.7d0/h0)*(1d0+z)**3d0/Ez
  do i=0,190
     hnu=1d0+dble(i)*1d-1 ! eV
     nu=hnu/h
     sum(1)=Lnu_ff(nu,Nstar)/mstar ! erg/Msun/Hz
     sum(2)=Lnu_fb(nu,Nstar)/mstar ! erg/Msun/Hz
     CALL qromb(meanLnu_star,dlog(m1),dlog(m2),res,nu)
     sum(3)=(res/denom)/mstar ! erg/Msun/Hz
     sum(5)=Lnu_2g(nu,Nstar)/mstar ! erg/Msun/Hz
!!$ Line approximation
     if(use_line_approximation)then
        sum(4)=L_lya(nu,Nstar)/mstar*(h/10.2d0) ! erg/Msun/Hz
     else
!!$ Santos et al.
        x=nulya-nu
        if(x>0d0)then
           sum(4)=Nstar*0.64d0*(10.2d0*eV2erg)/mstar &
               *nustar/x**2d0*dexp(-nustar/x) ! Eq(15) of Santos et al.
        else
           sum(4)=0d0
        endif
     endif
     write(1,'(7E15.5)')hnu,nu,nu*sum(1:5)*erg2nW/(tSF*3.1536d7)!nW/Msun
  enddo
  close(1)
END PROGRAM Compute_nuInu
!-------------------------------------------------------------
double precision FUNCTION Lnu_star(nu,m) ! erg/s/Hz
  USE pop3
  ! Stellar black-body spectrum, Lnu[erg/s/Hz]
  ! nu: frequency [Hz]
  ! m: stellar mass [Msun]
  IMPLICIT none
  double precision, intent(IN) :: nu,m
  double precision :: Bnu
  double precision :: h=4.136d-15   ! Planck's constant [eV s]
  double precision :: kB=8.61d-5    ! Boltzmann's constant [eV/K]
  double precision :: sigma=5.67d-5 ! Stephan-Boltzmann [erg/cm^2/K^4/s]
  double precision :: c=2.9979d10   ! Speed of light [cm/s]
  double precision :: eV2erg=1.602d-12 ! erg/eV
  double precision :: pi=3.1415926535d0
  Bnu=2d0*h*nu**3d0/c**2d0/(dexp(h*nu/kB/Teff(m))-1d0)
  Lnu_star=pi*(Lbol(m)/sigma/Teff(m)**4d0)*Bnu*eV2erg ! erg/s/Hz
  ! The prefactor, pi, was missing in Eq.(6) of Fernandez&Komatsu (2006)
END FUNCTION Lnu_star
!-------------------------------------------------------------
double precision FUNCTION Nion(lnm)
  USE salpeter
  USE pop3
! Nion(lnm) = m*f(m)*QH(m)*tau(m) 
! int_m1^m2 Nion(lnm) dlnm = [the total number of hydrogen ionizing 
!                            photons emitted duringthe main sequence 
!                            life time of stars]*norm
! where
! norm = int_m1^m2 m*f(lnm) dlnm
  IMPLICIT none
  double precision, intent(IN) :: lnm ! ln(m/Msun)
  double precision :: m
  m=dexp(lnm)
  Nion=m*f(m)*QH(m)*tau(m)
  return
END FUNCTION Nion
!-------------------------------------------------------------
double precision FUNCTION meanmass(lnm)
  USE salpeter
! meanmass(lnm) = m^2*f(m)
! int_m1^m2 meanmass(lnm) dlnm = [the mean stellar mass in units of Msun]*norm
! where 
! norm = int_m1^m2 m*f(lnm) dlnm
  IMPLICIT none
  double precision, intent(IN) :: lnm ! ln(m/Msun)
  double precision :: m
  m=dexp(lnm)
  meanmass=m**2d0*f(m)
  return
END FUNCTION meanmass
!-------------------------------------------------------------
double precision FUNCTION meanLnu_star(lnm,nu)
  USE salpeter
  USE pop3
! meanLnu_star(lnm) = m*f(m)*Lnu_star(nu,m)*tau(m)
! int_m1^m2 meanLnu_star(lnm) dlnm = [the mean stellar energy spectrum]*norm
! where 
! norm = int_m1^m2 m*f(lnm) dlnm
  IMPLICIT none
  double precision, intent(IN) :: nu,lnm ! ln(m/Msun)
  double precision :: m,Lnu_star
  double precision :: h=4.136d-15 ! Planck's constant [eV s]
  external Lnu_star
  m=dexp(lnm)
  if(h*nu<=13.6d0)then
     meanLnu_star=m*f(m)*Lnu_star(nu,m)*tau(m)
  else
     meanLnu_star=0d0
  endif
  return
END FUNCTION meanLnu_star
!-------------------------------------------------------------
double precision FUNCTION norm(lnm)
  USE salpeter
! integral of this function over m1<m<m2 gives the normalization.
  IMPLICIT none
  double precision, intent(IN) :: lnm ! ln(m/Msun)
  double precision :: m
  m=dexp(lnm)
  norm=m*f(m)
  return
END FUNCTION norm
