DOUBLE PRECISION FUNCTION Lnu_ff(nu,QH)
! Free-free luminosity spectrum per frequency of nebular emission
! around a star emitting the hydrogen-ionizing photons per second QH.
! - Lnu_ff: erg s^-1 Hz^-1
! - nu: Hz
! - QH: s^-1
! *** ASSUMPTIONS ***
! - Thermally-averaged Gaunt factor, gff = 1.1
! - Gas temperature, Tg = 10,000 K
! - Case-B recombination with phi_2(Tg)=1 (Table 5.2 of Spitzer'78)
! REF: Eq.(12) of Fernandez&Komatsu, ApJ, 646, 703 (2006)
!      Now we use a newer caseB recombination coefficient, 
!      alphaB=2.17d-10*Tg**(-0.7395) [cm^3/s]
  IMPLICIT none
  double precision, intent(IN) :: nu,QH
  double precision :: gff=1.1d0,Tg=1d4,phi2=1d0
  double precision :: h=4.1356668d-15 ! Planck's constant, eV s
  double precision :: kB=8.6173423d-05! Boltzmann's constant, eV K^-1
  !!$ Lnu_ff=3.32d22*(QH/1d49)*gff*phi2*exp(-h*nu/kB/Tg) ! with old alphaB, as in FK06
  Lnu_ff=6.8d-38*Tg**(-0.5d0)*QH*gff*phi2*exp(-h*nu/kB/Tg)/(2.17d-10*Tg**(-0.7395)) 
  return
END FUNCTION Lnu_ff
DOUBLE PRECISION FUNCTION Lnu_fb(nu,QH)
! Free-bound luminosity spectrum per frequency of nebular emission
! around a star emitting the hydrogen-ionizing photons per second QH.
! - Lnu_fb: erg s^-1 Hz^-1
! - nu: Hz
! - QH: s^-1
! *** ASSUMPTIONS ***
! - Free-bound Gaunt factor, gfb = 1.05
! - Gas temperature, Tg = 10,000 K
! - Case-B recombination with phi_2(Tg)=1 (Table 5.2 of Spitzer'78)
! REF: Eq.(12) of Fernandez&Komatsu, ApJ, 646, 703 (2006)
!      Now we use a newer caseB recombination coefficient, 
!      alphaB=2.17d-10*Tg**(-0.7395) [cm^3/s]
  IMPLICIT none
  double precision, intent(IN) :: nu,QH
  double precision :: gfb=1.05d0,Tg=1d4,phi2=1d0
  double precision :: h=4.1356668d-15 ! Planck's constant, eV s
  double precision :: kB=8.6173423d-05! Boltzmann's constant, eV K^-1
  double precision :: sum
  integer :: n
  sum=0d0
  do n=2,100
     if(h*nu*n**2d0>=13.6d0)then
        sum=sum+(13.6d0/kB/Tg)*exp(13.6d0/kB/Tg/n**2d0)/n**3d0*gfb
     else
        sum=0d0
     endif
  enddo
  !!$ Lnu_fb=3.32d22*(QH/1d49)*sum*phi2*exp(-h*nu/kB/Tg) ! with old alphaB, as in FK06
  Lnu_fb=6.8d-38*Tg**(-0.5d0)*QH*sum*phi2*exp(-h*nu/kB/Tg)/(2.17d-10*Tg**(-0.7395))
  return
END FUNCTION Lnu_fb
DOUBLE PRECISION FUNCTION Lnu_2g(nu,QH)
! Two-photon emission luminosity spectrum per frequency of nebular emission
! around a star emitting the hydrogen-ionizing photons per second QH.
! - Lnu_2g: erg s^-1 Hz^-1
! - nu: Hz
! - QH: s^-1
! *** ASSUMPTIONS ***
! - Lyman-alpha fraction, flya=0.64
! REF: Eq.(21) of Fernandez&Komatsu, ApJ, 646, 703 (2006)
  IMPLICIT none
  double precision, intent(IN) :: nu,QH
  double precision :: flya=0.64d0
  double precision :: h=6.626068d-27 ! Planck's constant, erg s
  double precision :: nu_lya=2.4663495d15 ! nu_Lya in units of Hz
  double precision :: y,P
  y=nu/nu_lya
  if(y>1)then
     P=0d0
  else
     P=1.307d0-2.627d0*(y-0.5d0)**2d0+2.563d0*(y-0.5d0)**4d0 &
          -51.69d0*(y-0.5d0)**6d0
  endif
  Lnu_2g=(2d0*h*nu/nu_lya)*(1d0-flya)*P*QH
  return
END FUNCTION Lnu_2g
DOUBLE PRECISION FUNCTION L_lya(nu,QH)
! Lyman-alpha luminosity of nebular emission (integrated over frequencies)
! around a star emitting the hydrogen-ionizing photons per second QH.
! - L_lya: erg s^-1
! - nu: Hz
! - QH: s^-1
! *** ASSUMPTIONS ***
! - Lyman-alpha fraction, flya=0.64
! REF: Eq.(19) of Fernandez&Komatsu, ApJ, 646, 703 (2006), integrated over nu
  IMPLICIT none
  double precision, intent(IN) :: nu,QH
  double precision :: flya=0.64d0
  double precision :: h=6.626068d-27 ! Planck's constant, erg s
  double precision :: nu_lya=2.4663495d15 ! nu_Lya in units of Hz
  if(abs(nu/nu_lya-1d0)<1d-5)then
     L_lya=flya*(h*nu_lya)*QH     
  else
     L_lya=0d0
  endif
  return
END FUNCTION L_lya
