MODULE pop3
contains
  double precision FUNCTION QH(m) ! 1/second
    ! The number of hydrogen-ionizing photons per second, QH [1/s]
    ! Ref: D. Schaerer, A&A, 382, 28 (2002)
    IMPLICIT none
    double precision, intent(IN) :: m ! Msun
    double precision :: y,logQH
    y=dlog10(m)
    if(m>=9d0)then
       logQH=43.61d0+4.9d0*y-0.83d0*y**2d0
    else if(m>=5d0)then
       logQH=39.29d0+8.55d0*y
    else
       logQH=0d0
    endif
    QH=10d0**logQH ! [1/second]
    return
  END FUNCTION QH
  double precision FUNCTION tau(m) ! seconds
    ! The main-sequence life time, tau [s]
    ! Ref: D. Schaerer, A&A, 382, 28 (2002) for m>10 Msun
    !      P. Marigo et al, A&A, 371, 152 (2001) for m<10 Msun
    IMPLICIT none
    double precision, intent(IN) :: m ! Msun
    double precision :: y,logtau
    y=dlog10(m)
    if(m>=10d0)then
       logtau=9.79d0-3.76d0*y+1.41d0*y**2d0-0.186d0*y**3d0
    else
       logtau=9.80d0-3.52d0*y+1.18d0*y**2d0-0.164d0*y**3d0
    endif
    tau=10d0**logtau*3.1536d7 ! in seconds
  END FUNCTION tau
  double precision FUNCTION Teff(m) ! Kelvin
    ! Stellar effective temperature, Teff [K]
    ! Ref: D. Schaerer, A&A, 382, 28 (2002) for m>10 Msun
    !      P. Marigo et al, A&A, 371, 152 (2001) for m<10 Msun
    IMPLICIT none
    double precision, intent(IN) :: m ! Msun
    double precision :: y,logTeff
    y=dlog10(m)
    if(m>=10d0)then
       logTeff=3.64d0+1.50d0*y-0.556d0*y**2d0+0.070d0*y**3d0
    else
       logTeff=3.87d0+0.937d0*y-0.156d0*y**2d0
    endif
    Teff=10d0**logTeff
  END FUNCTION Teff
  double precision FUNCTION Lbol(m) ! erg/s
    ! Stellar bolometric luminosity, Lbol [erg/s]
    ! Ref: D. Schaerer, A&A, 382, 28 (2002) for m>10 Msun
    !      P. Marigo et al, A&A, 371, 152 (2001) for m<10 Msun
    IMPLICIT none
    double precision, intent(IN) :: m ! Msun
    double precision :: y,logLbol
    y=dlog10(m)
    if(m>=10d0)then
       logLbol=0.457d0+3.90d0*y-0.530d0*y**2d0
    else
       logLbol=0.219d0+4.51d0*y-0.923d0*y**2d0
    endif
    Lbol=10d0**logLbol*3.826d33 ! erg/s
  END FUNCTION Lbol
END MODULE pop3
